`ecutilities`
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Installation:

**PyPi**

`pip install ecutilities`

**GitHub**

Two options to get versions which are not yet released on PyPi:

1.  clone the github [repo](https://github.com/vtecftwy/ecutils) and
    install it in edit mode from within the cloned repo:

<!-- -->

    pip install -e .

2.  install with pip from the github repo directly for hosted virtual
    machines:

<!-- -->

    pip install git+https://github.com/vtecftwy/ecutils.git@master
    pip install git+https://github.com/vtecftwy/ecutils.git@develop

## Modules:

0.  General use:
    - `core`
    - `ipython`
    - `plotting`
1.  Data Science and Machine learning:
    - `eda_stats_utils`
    - `ml`
2.  Images
    - `image_utils`
3.  Development
    - `dev_utils`
